#!/bin/sh
CONF=/etc/config/qpkg.conf																						# Location of QPKG conf file
QPKG_NAME="PlexMediaServer"																						# Name of PMS install dir
QPKG_DIR=$(getcfg -f $CONF $QPKG_NAME Install_path)										# Grap PMS install dir, regardless of disk layout
PID_FILE="${QPKG_DIR}/Library/Plex Media Server/plexmediaserver.pid"

case "$1" in
  start)
    ENABLED=$(/sbin/getcfg $QPKG_NAME Enable -u -d FALSE -f $CONF)
    if [ "$ENABLED" != "TRUE" ]; then
        echo "$QPKG_NAME is disabled."
        exit 1
    fi	
    if [ -f "$PID_FILE" ]; then
      logMsg="Plex Media Server is currently running or hasn't been shutdown properly. Please stop it from QNAP AppCenter and start it again."
      echo $logMsg
      /sbin/log_tool -t 2 -a "$logMsg"
      exit 0
    fi
    logMsg="Starting Plex Media Server..."
    echo $logMsg
    /sbin/log_tool -t 0 -a "$logMsg"
    export PLEX_MEDIA_SERVER_MAX_PLUGIN_PROCS=6
    export LC_ALL=en_US.UTF-8
    export LANG=en_US.UTF-8
    export LANGUAGE=en_US.UTF-8
    export PLEX_MEDIA_SERVER_APPLICATION_SUPPORT_DIR="${QPKG_DIR}/Library"
    export TMPDIR="${QPKG_DIR}/Library/tmp"
    export LD_LIBRARY_PATH=${QPKG_DIR}
    #Wait a little bit, since new firmware seems to cause a race condition
    sleep 5
    ulimit -s 3000
    cd ${QPKG_DIR}
    ./Plex\ Media\ Server &		
		  ;;

  stop)
    if [ ! -f "$PID_FILE" ]; then
      logMsg="Plex Media Server hasn't been enabled or started ..."
      echo $logMsg
      /sbin/log_tool -t 2 -a "$logMsg"
      exit 0
    else
      logMsg="Stopping Plex Media Server..."
      echo $logMsg
      /sbin/log_tool -t 0 -a "$logMsg"
      kill $(<$PID_FILE)
      # If pid file is a leftover from not shutting down properly, remove it now
      if [ -f "$PID_FILE" ]; then
        rm "$PID_FILE"
      fi
    fi		
		  ;;

  restart)
    $0 stop
    sleep 5
    $0 start
    ;;

  *)
    echo "Usage: $0 {start|stop|restart}"
    exit 1
esac

exit 0

